@@ -4,13 +4,13 @@ WSGI config for test_project project.
 It exposes the WSGI callable as a module-level variable named ``application``.
 
 For more information on this file, see
-https://docs.djangoproject.com/en/1.11/howto/deployment/wsgi/
+https://docs.djangoproject.com/en/4.0/howto/deployment/wsgi/
 """
 
 import os
 
 from django.core.wsgi import get_wsgi_application
 
-os.environ.setdefault("DJANGO_SETTINGS_MODULE", "test_project.settings")
+os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'test_project.settings')
 
 application = get_wsgi_application()
